@@ -7,18 +7,20 @@
 # You may use and distribute this software under the same terms and conditions
 # as Perl itself.
 
-package PkgConfig::Vars;
+package
+    PkgConfig::Vars;
 # this is a namespace for .pc files to hold their variables without
 # relying on lexical scope.
 
-package PkgConfig::UDefs;
+package
+    PkgConfig::UDefs;
 # This namespace provides user-defined variables which are to override any
 # declarations within the .pc file itself.
 
 package PkgConfig;
 
 #First two digits are Perl version, second two are pkg-config version
-our $VERSION = '0.07620';
+our $VERSION = '0.07720';
 
 require 5.006;
 
@@ -456,7 +458,19 @@ sub find {
     
         foreach my $lib (@libraries) {
             $o->recursion(0);
+            my($op,$ver);
+            ($lib,$op,$ver) = ($1,$2,PkgConfig::Version->new($3))
+                if $lib =~ /^(.*)\s+(!=|=|>=|<=|>|<)\s+(.*)$/;
             $o->find_pcfile($lib);
+            
+            if(!$o->errmsg && defined $op) {
+                $op = '==' if $op eq '=';
+                unless(eval qq{ PkgConfig::Version->new(\$o->pkg_version) $op \$ver })
+                {
+                    $o->errmsg("Requested '$lib $op $ver' but version of $lib is " . 
+                        ($o->pkg_version ? $o->pkg_version : '') . "\n");
+                }
+            }
         }
     }
     
@@ -733,6 +747,11 @@ sub get_ldflags {
     return @ret;
 }
 
+sub get_var {
+    my($self, $name) = @_;
+    $self->_pc_var($name);
+}
+
 sub get_list {
     my $self = shift;
     my @search_paths = @{$self->search_path};
@@ -840,6 +859,34 @@ if(caller) {
     return 1;
 }
 
+package
+    PkgConfig::Version;
+
+use overload
+    '<=>' => sub { $_[0]->cmp($_[1]) },
+    '""'  => sub { $_[0]->as_string },
+    fallback => 1;
+
+sub new {
+    my($class, $value) = @_;
+    bless [split /\./, defined $value ? $value : ''], $class;
+}
+
+sub clone {
+    __PACKAGE__->new(shift->as_string);
+}
+
+sub as_string {
+    my($self) = @_;
+    join '.', @{ $self };
+}
+
+sub cmp {
+    my($self, $other) = @_;
+    no warnings 'uninitialized';
+    defined($self->[0]) || defined($other->[0]) ? ($self->[0] <=> $other->[0]) || &cmp([@{$self}[1..$#$self]], [@{$other}[1..$#$other]]) : 0;
+}
+
 ################################################################################
 ################################################################################
 ################################################################################
@@ -977,6 +1024,15 @@ if($ListAll) {
 }
 
 my @FINDLIBS = @ARGV or die "Must specify at least one library";
+
+if($AtLeastVersion) {
+    @FINDLIBS = map { "$_ >= $AtLeastVersion" } @FINDLIBS;
+} elsif($MaxVersion) {
+    @FINDLIBS = map { "$_ <= $MaxVersion" } @FINDLIBS;
+} elsif($ExactVersion) {
+    @FINDLIBS = map { "$_ = $ExactVersion" } @FINDLIBS;
+}
+
 my $o = PkgConfig->find(\@FINDLIBS, %pc_options);
 
 if($o->errmsg) {
@@ -984,31 +1040,6 @@ if($o->errmsg) {
     exit(1);
 }
 
-if($ExactVersion) {
-    exit(2) unless $o->pkg_version eq $ExactVersion;
-}
-
-sub _is_greater_than_or_equal ($$)
-{
-    my @a = split /\./, shift;
-    my @b = split /\./, shift;
-    while(@a || @b) {
-        my $a = shift(@a) || 0;
-        my $b = shift(@b) || 0;
-        return 1 if $a > $b;
-        return 0 if $a < $b;
-    }
-    return 1;
-}
-
-if($AtLeastVersion) {
-    exit(2) unless _is_greater_than_or_equal($o->pkg_version, $AtLeastVersion);
-}
-
-if($MaxVersion) {
-    exit(2) unless _is_greater_than_or_equal($MaxVersion, $o->pkg_version);
-}
-
 if($o->print_variables) {
     while (my ($k,$v) = each %{$o->defined_variables}) {
         print $k;
@@ -1093,6 +1124,7 @@ Compare to:
     if($o->errmsg) {
         #handle error
     } else {
+        my $prefix = $o->get_var('prefix');
         my @cflags = $o->get_cflags;
         my @ldflags = $o->get_ldflags;
     }
@@ -1304,6 +1336,10 @@ The version of the package
 
 Returns a list of compiler and linker flags, respectively.
 
+=head4 I<< $o->get_var($name) >>
+
+Get the variable with the given name.
+
 =head4 I<< PkgConfig->Guess >>
 
 This is a class method, and will replace the hard-coded default linker and include
@@ -1346,6 +1382,10 @@ Example, don't install any scripts:
 
  % perl Makefile.PL --script none
 
+You can also set the environment variable PERL_PKG_CONFIG_SCRIPTS to the
+desired --script value (separating each script name with a comma C<,>) to
+ensure that upgrades of PkgConfig do the same.
+
 =head2 CAVEATS
 
 On Strawberry Perl C<ppkg-config> acts like Strawberry is the system.  
@@ -1383,12 +1423,26 @@ package itself (without dependencies).
 
 =head1 SEE ALSO
 
-L<ExtUtils::PkgConfig>, a wrapper around the C<pkg-config> binary
+=over 4
 
-L<pkg-config|http://www.freedesktop.org/wiki/Software/pkg-config>
+=item L<pkg-config|http://www.freedesktop.org/wiki/Software/pkg-config>
 
-L<http://www.openbsd.org/cgi-bin/cvsweb/src/usr.bin/pkg-config/> another 
-perl implementation of pkg-config
+The original C implementation
+
+=item L<ExtUtils::PkgConfig>
+
+A wrapper around the C<pkg-config> binary that can be used in your C<Makefile.PL>
+or C<Build.PL>.
+
+=item L<http://www.openbsd.org/cgi-bin/cvsweb/src/usr.bin/pkg-config/>
+
+Another perl implementation of pkg-config
+
+=item L<pkgconf|https://github.com/pkgconf/pkgconf>
+
+An alternative C implementation
+
+=back
 
 =head1 AUTHOR
 
